@@ -89,26 +89,27 @@ int send_cmd(struct unix_ctx *ctx, unsigned cmd, const void *data,
 	struct iovec iov[2];
 	unsigned iov_len = 1;
 	int e, ret;
-	uint16_t length = 0;
+	uint16_t rlength = 0;
+	uint32_t length32 = 0;
 	void *packed = NULL;
 
 	if (get_size)
-		length = get_size(data);
+		rlength = get_size(data);
 
 	header[0] = cmd;
-	memcpy(&header[1], &length, 2);
+	memcpy(&header[1], &rlength, 2);
 
 	iov[0].iov_base = header;
 	iov[0].iov_len = 3;
 
 	if (data != NULL) {
-		packed = talloc_size(ctx, length);
+		packed = talloc_size(ctx, rlength);
 		if (packed == NULL) {
 			fprintf(stderr, "memory error\n");
 			return -1;
 		}
 		iov[1].iov_base = packed;
-		iov[1].iov_len = length;
+		iov[1].iov_len = rlength;
 		
 		ret = pack(data, packed);
 		if (ret == 0) {
@@ -128,7 +129,7 @@ int send_cmd(struct unix_ctx *ctx, unsigned cmd, const void *data,
 	}
 
 	if (rep != NULL) {
-		ret = force_read_timeout(ctx->fd, header, 3, DEFAULT_TIMEOUT);
+		ret = force_read_timeout(ctx->fd, header, 1+sizeof(length32), DEFAULT_TIMEOUT);
 		if (ret == -1) {
 			/*e = errno;
 			fprintf(stderr, "read: %s\n", strerror(e));*/
@@ -136,7 +137,7 @@ int send_cmd(struct unix_ctx *ctx, unsigned cmd, const void *data,
 			goto fail;
 		}
 
-		if (ret != 3) {
+		if (ret != 1+sizeof(length32)) {
 			fprintf(stderr, "short read %d\n", ret);
 			ret = -1;
 			goto fail;
@@ -150,17 +151,17 @@ int send_cmd(struct unix_ctx *ctx, unsigned cmd, const void *data,
 			goto fail;
 		}
 
-		memcpy(&length, &header[1], 2);
+		memcpy(&length32, &header[1], 4);
 
-		rep->data_size = length;
-		rep->data = talloc_size(ctx, length);
+		rep->data_size = length32;
+		rep->data = talloc_size(ctx, length32);
 		if (rep->data == NULL) {
 			fprintf(stderr, "memory error\n");
 			ret = -1;
 			goto fail;
 		}
 
-		ret = force_read_timeout(ctx->fd, rep->data, length, DEFAULT_TIMEOUT);
+		ret = force_read_timeout(ctx->fd, rep->data, length32, DEFAULT_TIMEOUT);
 		if (ret == -1) {
 			e = errno;
 			talloc_free(rep->data);
