@@ -210,7 +210,8 @@ static int setup_dtls_connection(struct worker_st *ws)
 	ret = gnutls_session_set_premaster(session, GNUTLS_SERVER,
 					   ws->req.
 					   selected_ciphersuite->gnutls_version,
-					   GNUTLS_KX_RSA,
+					   ws->req.
+					   selected_ciphersuite->gnutls_kx,
 					   ws->req.
 					   selected_ciphersuite->gnutls_cipher,
 					   ws->req.
@@ -774,6 +775,12 @@ int periodic_check(worker_st * ws, unsigned mtu_overhead, struct timespec *tnow,
 	if (now - ws->last_periodic_check < periodic_check_time)
 		return 0;
 
+	/* we set an alarm at each periodic check to prevent any
+	 * freezes in the worker due to an unexpected block (due to worker
+	 * bug or kernel bug). In that case the worker will be killed due
+	 * the the alarm instead of hanging. */
+	alarm(1800);
+
 	if (ws->config->idle_timeout > 0) {
 		if (now - ws->last_nc_msg > ws->config->idle_timeout) {
 			oclog(ws, LOG_ERR,
