@@ -22,9 +22,21 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 #this test can only be run as root
-id|grep root >/dev/null 2>&1
-if [ $? != 0 ];then
-	exit 77
+
+OPENCONNECT=/usr/sbin/openconnect
+
+if test -z "$NO_NEED_ROOT";then
+	id|grep root >/dev/null 2>&1
+	if [ $? != 0 ];then
+		exit 77
+	fi
+else
+	SOCKDIR=${srcdir}/sockwrap.$$.tmp
+	mkdir -p $SOCKDIR
+	export SOCKET_WRAPPER_DIR=$SOCKDIR
+	export SOCKET_WRAPPER_DEFAULT_IFACE=2
+	ADDRESS=127.0.0.$SOCKET_WRAPPER_DEFAULT_IFACE
+	OPENCONNECT="eval LD_PRELOAD=libsocket_wrapper.so /usr/sbin/openconnect"
 fi
 
 if ! test -x /usr/sbin/openconnect;then
@@ -32,7 +44,12 @@ if ! test -x /usr/sbin/openconnect;then
 	exit 77
 fi
 
-OPENCONNECT=/usr/sbin/openconnect
+update_config() {
+	file=$1
+	cp ${srcdir}/${file} "$file.tmp"
+	sed -i 's|@SRCDIR@|'${srcdir}'|g' "$file.tmp"
+	CONFIG="$file.tmp"
+}
 
 fail() {
    PID=$1
@@ -54,8 +71,24 @@ launch_server() {
        fi
 }
 
+launch_sr_server() {
+       LD_PRELOAD=libsocket_wrapper.so:libuid_wrapper.so UID_WRAPPER=1 UID_WRAPPER_ROOT=1 $SERV $* &#>/dev/null 2>&1 &
+       LOCALPID="$!";
+       trap "[ ! -z \"${LOCALPID}\" ] && kill ${LOCALPID};" 15
+       wait "${LOCALPID}"
+       LOCALRET="$?"
+       if [ "${LOCALRET}" != "0" ] && [ "${LOCALRET}" != "143" ] ; then
+               # Houston, we'v got a problem...
+               exit 1
+       fi
+}
+
+launch_simple_sr_server() {
+       LD_PRELOAD=libsocket_wrapper.so:libuid_wrapper.so UID_WRAPPER=1 UID_WRAPPER_ROOT=1 $SERV $* >/dev/null 2>&1 &
+}
+
 launch_simple_server() {
-       $SERV $* >/dev/null 2>&1 &
+       $PRELOAD_CMD $SERV $* >/dev/null 2>&1 &
 }
 
 launch_debug_server() {
@@ -75,4 +108,16 @@ wait_server() {
 	sleep 5
 }
 
+cleanup() {
+	ret=0
+	kill $PID
+	if test $? != 0;then
+		ret=1
+	fi
+	wait
+	test -n "$SOCKDIR" && rm -rf $SOCKDIR
+	rm -f ${CONFIG}
+	return $ret
+}
+
 trap "fail \"Failed to launch the server, aborting test... \"" 10 
